@@ -11,7 +11,11 @@ def append_twiss_gamma(twiss_df):
     gamma_y = _calculate_twiss_gamma(twiss_df.ALFY, twiss_df.BETY)
     return twiss_df.assign(GAMX=gamma_x, GAMY=gamma_y)
 
-def append_beam_size_columns(twiss_df, emitnx, emitny, espread_norm):
+def append_beam_size_columns(twiss_df,
+                             emitnx: float, emitny: float,
+                             espread_norm: float):
+    fix_initial_row_energy(twiss_df)
+
     relgamma = twiss_df.E / MASS_ELECTRON_GEV
     emitx = emitnx / relgamma
     emity = emitny / relgamma
@@ -28,14 +32,17 @@ def append_beam_size_columns(twiss_df, emitnx, emitny, espread_norm):
     twiss_df = twiss_df.assign(SIGMAX=sigma_x,
                                SIGMAY=sigma_y,
                                SIGMAXP=sigma_xp,
-                               SIGMAYP=sigma_yp
-                               )
-    from IPython import embed; embed()
+                               SIGMAYP=sigma_yp)
 
     return twiss_df
 
-def fix_initial_element(twiss_df):
-    pass
+def fix_initial_row_energy(twiss_df):
+    """Initial row always has 0 energy, so set it to the next element's energy,
+    which is fine unless the first element changes the energy (unlikely)"""
+    initial = twiss_df.iloc[0]
+    nxt = twiss_df.iloc[1]
+    if initial.E == 0.0:
+        initial.E = nxt.E
 
 def append_s_column(twiss_df):
     return twiss_df.assign(S=twiss_df.SUML)
